---
title: "Mill vs Aristotle: The Summum Bonum That Wasn't"
date: 2018-11-18T23:20:43Z
tags: ["virtue ethics","utilitarianism","pleasure","happiness"]
topics: ["philosophy"]
image: /img/mill-and-aristotle.jpg
draft: false
---

In a [previous post](http://philosophy.gmgauthier.com/plato-versus-mill-on-the-pleasure-principle-mill-loses/), I outlined some significant differences between Mill and Plato on the question of Pleasure, that I think are grounded in a misreading of Plato. Here, I present a few differences between Mill and Aristotle on the *summum bonum*, right and wrong action, and pleasure.

When considering the arguments in Utilitarianism, and the obvious allusions to Plato and Aristotle within it, many seem to me to be incomplete at best, and misguided at worst. The main disagreement, almost from the start, is on the question of both what constitutes a “chief good” (and how its justified), and what the chief good actually is. Namely, what is *happiness*. As we’ll see, this divergence is immediate, and catastrophic. Mill is clearly adopting Aristotle’s framing of the problem of morality, as one in which we must identify the highest good, and then justify our actions relative to it:

> “All action is for the sake of some end, and rules of action, it seems natural to suppose, must take their whole character and colour from the end to which they are subservient.” — Mill

But Aristotle takes this a step further in his introduction, positing the *summum bonum* almost immediately:

> “Every art and every inquiry, and similarly every action and choice, is though to aim at some good; and it is for this reason, the good has rightly been declared to be that at which all things aim… If, then, there is some chief end of the things we do, which we desire for its own sake (everything else being desired for the sake of this)… clearly this must be the chief good. Will not knowledge of it, then, have a great influence on life? Shall we not, like archers who have a mark to aim at, be more likely to hit upon what is right?…” — Aristotle

Mill agrees that the question of how we decide right action from wrong is the same as the identification of the *summum bonum*; or, the explication of the foundations of morality, but:

> “…a test of right and wrong must be the means… of ascertaining what is right and wrong, and *not a consequence of already having ascertained it*…” – Mill

To the question of determining right and wrong action, prior to knowing the chief good, Aristotle argues that this is not as easy as it sounds:

> “Noble and just actions… exhibit much variety and fluctuation, so they may be thought to exist only by convention, and not by nature. But goods exhibit a similar fluctuation because they bring harm to many people; for in the past, men have been undone by reason of their wealth, and others by reason of their courage…” — Aristotle

Mill responds, stretching the problem by arguing that there is no special faculty by which we can know what the chief good is:

> “…the existence of a [natural] moral instinct is itself one of the matters of dispute… our moral faculty, according to all those of its interpreters… supplies us only with the general principles of moral judgment; it is a branch of our reason, not of our sensitive faculty; and must be looked to for abstract doctrines of morality, not for perception of it in the concrete…” — Mill

But Aristotle insists that what is evident to us by reason should be enough to at least recognize the *summum bonum* as Eudaemonia:

> “…both the general run of men, and people of superior refinement, say that [the *summum bonum*] is [Eudaemonia] and identify living well and flourishing with this; but with regard to what [Eudaemonia] is they differ, and the masses do not give the same account as the wise. For the former think it is something plain and obvious, like pleasure, wealth, or honour… let us not fail to notice, however, that there is a difference between arguments from an those *to* the first principles… while we must begin with what is evident, things are evident in two ways – some to us, some without qualification. Presumably, then, we must begin with things that are evident *to us*…” — Aristotle

Mill seems to agree that a first principle is necessary, but insists it cannot be Eudaemonia, arguing for the pleasure principle instead:

> “…[Aristotelians hold] that morality must be deduced from first principles to support their pretensions that there ought to be either some fundamental principle or law at the root of morality, or if there be several, there should be a determinate order of precedence among them… the non-existence of an acknowledged first principle has made ethics not so much a guide as a consecration of mens actual sentiments. Still, as mens sentiments, both of favor and aversion, are greatly influenced by what they suppose to be the effects of things upon their happiness [pleasure], the principle of utility, or as Bentham latterly called it, the Greatest Happiness Principle…” — Mill

Mill goes much further in his skepticism, as well, insisting that first principles cannot be justified:

> “…questions of ultimate ends are not amenable to direct proof. Whatever can be proved to be good, must be so by being shown to be a means to something admitted to be good without proof. The medical art is proved to be good by its conducing to health, but how is it possible to prove that health is good?…” — Mill

To which Aristotle retorts that Mill has forgotten to infer the Telos from the design or function of man, himself:

> “…Let us return to the good we are seeking, and ask what it can be… Surely that for which sake everything else is done. In medicine this is health… it is for the sake of the [chief good] that all men do whatever they do. Therefore, there is an end for all that we do, this will be the good achievable by action… the chief good is evidently something final… we call final without qualification that which is always desirable in itself, and never for the sake of something else… Eudaemonia above all else, is held to be [final], for this we choose always for itself and never for the sake of something else; honour, pleasure, reason, and every virtue, we choose indeed for themselves, but we choose them also for the sake of Eudaemonia, judging that through them, we shall achieve a life of Eudamonia…” — Aristotle

Mill rejects this, insisting that Eudaemonia is a myth, and simply asserting that all this ever really meant, was pleasure:

> “…every writer from Epicurus to Bentham, who maintained a theory of utility, meant by it, not something to be contradistinguished from pleasure, but pleasure itself, together with the exemption from pain; and instead of opposing the useful to the agreeable or the ornamental, have always declared that the useful means these, among other things…” — Mill

But Aristotle *did* make this “contradistinction” (and, arguably, so did Socrates). He adopts a similar tripartite psychology to Plato’s, even while disputing Plato:

> “…Let us separate, then, things good in themselves from useful things, and consider whether the former are called good by reference to a single Form… of honour, wisdom, and pleasure. Just in respect of their goodness, the accounts are distinct and diverse. The good, therefore, is not something common answering to one idea. But what then do we mean by the good?…” — Aristotle

Aristotle’s answer to this question is Eudaemonia, as mentioned before. And the three goods of honour, wisdom, and pleasure, answer to it.

Mill completely ignores the idea of Eudaemonia, blithely ploughing ahead with his equation of happiness and pleasure. He did concede, at least, two kinds of pleasure (a trap that Socrates also laid for Callicles in The Gorgias, and as I mentioned in my previous post, Mill also chose to ignore):

> “…Human beings have faculties more elevated than the animal appetites, and whence once made conscious of them, do not regard anything as happiness which does not include their gratification…” — Mill

The trap, is that this implies a standard by which “high” and “low” pleasures can be judged. Aristotle partly agrees, and again, articulates his tripartite view. But says that Mill is mistaken to think that high borns aren’t susceptible to low pleasures:

> “…the mass of mankind are evidently quite slavish in their tastes, preferring a life suitable to beasts, but they get some ground for their view from the fact that many of those in the high places share the tastes of Sardanapallus. A further consideration of the prominent types of life shows that people of superior refinement and of active disposition identify Eudaemonia with honour; for this is, roughly speaking, the end of political life… the third kind of life, is the contemplative life…” — Aristotle

Mill’s task, then, is to name this standard, and explain why pleasure is to be adopted to the exclusion of honour or wisdom, and Eudaemonia is to be jettisoned altogether. He never really does this. The best he can offer, is a slightly better enumeration of the kinds of pleasure, than Callicles could offer, in the Gorgias:

> “…of two pleasures, if there be one to which all or most give a decided preference, irrespective of any feeling of moral obligation to prefer it, that is the more desirable pleasure… if one of the two [pleasures] is, by those who are competently acquainted with both, placed so far above the other that they prefer it even though knowing it to be attended with a greater amount of discontent… we are justified in ascribing to the preferred enjoyment a superiority in quality…” — Mill

So, there is no standard beyond a democratic vote, among the “competently acquainted”. Mill never explains what would constitute competent acquaintance, or why a democratic majority constitutes a standard for “superiority in quality”.

Aristotle differed from Mill dramatically on the question of pleasure. He did not reject it as the ascetics did. He did not elevate it to the *summum bonum* the way Mill has. Rather, in addition to conceding it as one pathway or life among the three that leads to Eudaemonia, he also saw it as an instrumental good. It is an “instrument reading” telling us whether we’re achieving what we hold valuable (what we love). To wit:

> “…pleasure is a state of the soul, and to each man, that which he is said to be a lover of, is pleasant; for example, not only is a horse pleasant to a lover of horses, and a spectacle to a lover of sights, so too in the same way are just acts pleasant to the lover of justice and in general virtuous actions to the lover of virtue… the lovers of what is noble find pleasant the things that are by nature pleasant; virtuous actions are such, so that these are pleasant for such men as well as in their own nature… the man who does not rejoice in noble actions is not even good, since no one would call a man just who did not enjoy acting justly…” — Aristotle

The question of Mill’s disagreement with Aristotle on the topics of virtue and justice is so large and complicated that I’m going to have to address it in another post. Suffice to say here, that the divergence between Aristotle and Mill after the question of the *summum bonum* and the pleasure principle is so great, that by the time we get to virtue and justice, the two are utterly unrecognizable.

Ultimately, I think Plato and Aristotle in combination, have actually presented a far richer and more sophisticated picture of moral psychology, than Mill has. His idea, even while borrowing Aristotle’s good-centered morality, is heavily dependent upon appeals to Victorian sentimentality, and an implicit reliance on progressive notions of the development of history and human society that require utopian optimism. What’s more, as I’ve outlined here and in the previous post, he reduces all of human motivation to a single variable — pleasure — and fails to explain why his conception of the pleasure principle is impervious to the objections presented by Plato and Aristotle — the two philosophers beyond Bentham that lurk constantly in the background of everything Mill did.

Thus, while Utilitarianism may provide some utility (pun not intended) in very localized and immediate circumstances, I do not think it is sufficient as a theory of morality in general, nor a palatable model for moral decision-making.

```[Imported from exitingthecave.com on 29 November 2021]```

