---
title: "Postmodern Censoriousness"
author: "Stephen Hicks"
image: /img/stephen-hicks.jpg
era: "Contemporary"
topic: "Free Speech"
draft: false
---

*The following is an excerpt from Stephen Hicks’ [“Free Speech and Postmodernism”](http://www.stephenhicks.org/wp-content/uploads/2012/01/hicks-freespeechpostmodernism.pdf)*

**The Censoriousness of Postmodernism**

The Social Construction of Minds

Traditionally, speech has been seen as an individual cognitive act. The postmodern view, by contrast, is that speech is formed socially in the individual. And since what we think is a function of what we learn linguistically, our thinking processes are constructed socially, depending on the linguistic habits of the groups we belong to. From this epistemological perspective, the notion that individuals can teach themselves or go their own way is a myth. Also, the notion that we can take someone who has been constructed as a racist and simply teach him to unlearn his bad habits, or teach a whole group to unlearn its bad habits, by appealing to their reason—that also is a myth…

…We are constructed socially, the postmoderns argue, and we are, even as adults, not aware of the social construction that underlies the speech we are engaging in. We might feel as though we are speaking freely and making our own choices, but the unseen hand of social construction is making us what we are. What you think and what you do and even how you think are governed by your background beliefs.

[Stanley] Fish states the point abstractly. Catharine MacKinnon applies this point to the special case of women and men, in making her case for censoring pornography. Her argument is not the standard, conservative argument that pornography desensitizes men and gets them riled up to the point where they go out and do brutal things to women. MacKinnon believes that pornography does that, but her argument is deeper. She argues that pornography is a major part of the social discourse that is constructing all of us. It makes men what they are in the first place and it makes women what they are in the first place. So we are culturally constructed by porn as a form of language to adopt certain sex roles and so forth.

As a result of this, the postmoderns infer there is no distinction between speech and action, a distinction that liberals have traditionally prized. According to postmodernists, speech is itself something that is powerful because it constructs who we are and underlies all of the actions that we engage in. And as a form of action, it can and does cause harm to other people. Liberals, say postmodernists, should accept that any form of harmful action must be constrained. Therefore, they must accept censorship.

Another consequence of this view is that group conflict is inevitable, for different groups are constructed differently according to their different linguistic and social backgrounds. Blacks and whites, men and women, are constructed differently and those different linguistic-social-ideological universes will clash with each other. Thus, the speech of the members of each group is seen as a vehicle through which the groups’ competing interests clash. And there will be no way of resolving the clash, because from this perspective you cannot say, “Let’s settle this reasonably.” What reason is, is itself constructed by the prior conditions that made you what you are. What seems reasonable to you is not going to be what is reasonable to the other group. Consequently, the whole discussion is necessarily going to descend into a shouting match.

Let’s summarize this argument and put all of its elements together.

- Speech is a form of social power. [Social Constructivism]
- Fairness means an equal ability to speak. [Egalitarianism]
- The ability to speak is unequal across racial and sexual groups. [Collectivism]
- The races and sexes are in conflict with each other. [Racism and Sexism]
- The stronger racial and sexual groups, that is, whites and males, will use speech-power to their advantage, at the expense of other races and women. [Zero-Sum Conflict]

What we have, then, are two positions about the nature of speech. The postmoderns say: Speech is a weapon in the conflict between groups that are unequal. And that is diametrically opposed to the liberal view of speech, which says: Speech is a tool of cognition and communication for individuals who are free.

If we adopt the first statement, then the solution is going to be some form of enforced altruism, under which we redistribute speech in order to protect the harmed, weaker groups. If the stronger white males have speech tools they can use to the detriment of the other groups, then do not let them use those speech tools. Generate a list of denigrating words that harm members of the other groups and prohibit members of the powerful groups from using them. Do not let them use the words that reinforce their own racism and sexism, and don’t let them use words that make members of other groups feel threatened. Eliminating those speech advantages will reconstruct our social reality—which is the same goal as affirmative action.

A striking consequence of this analysis is that the toleration of “anything goes” in speech *becomes censorship*. The postmodern argument implies that if anything goes, then that gives permission to the dominant groups to keep on saying the things that keep the subordinate groups in their places. Liberalism thus means helping the silencing of the subordinate groups and letting only the dominant groups have effective speech. Postmodern speech codes, therefore, are not censorship but a form of liberation—they liberate the subordinated groups from the punishing and silencing effects of the powerful groups’ speech, and they provide an atmosphere in which the previously subordinated groups can express themselves. Speech codes equalize the playing field.

As Stanley Fish says:

> Individualism, fairness, merit—these three words are continually in the mouths of our up-to-date, newly respectable bigots who have learned that they need not put on a white hood or bar access to the ballot box in order to secure their ends.

In other words, free speech is what the Ku Klux Klan favors.

The liberal notions of leaving individuals free and telling them that we are going to treat them according to the same rules and judge them on their merit—according to the postmodern Left, that only means reinforcing the status quo, which means keeping the whites and males on top and the rest below. So in order to equalize the power imbalance, explicit and forthright double-standards are absolutely and unapologetically called for by the postmodern Left.

The Justification of Freedom of Speech

…Three broad points must be made. The first is an ethical point: individual autonomy. We live in reality, and it is absolutely important to our survival that we come to understand that reality. But coming to know how the world works and acting on the basis of that knowledge is an individual responsibility. Exercising that responsibility requires social freedoms, and one of the social freedoms that we need is speech. We have the capacity to think or not. But that capacity can be hampered severely by a social atmosphere of fear. That is an indispensable part of the liberal argument. Censorship is a tool of government: the government has the power of force to achieve its end, and depending on how that force is used it can generate an atmosphere of fear that interferes with an individual’s ability to perform the basic cognitive functions he needs to act responsibly in the world.

Second is a social point: We get all sorts of values from each other. I will use David Kelley’s social-value categorization scheme here: in social relationships we exchange knowledge values, friendship and love values, and economic trade values. Often, the pursuit of knowledge values is conducted in specialized institutions, and within those institutions the discovery of truth requires certain protections. If we are going to learn from each other and if we are going to be able to teach others, then we need to be able to engage in certain kinds of social processes: debate, criticism, lecturing, asking stupid questions, and so on. All of that presupposes a key social principle: that we will tolerate those things in our social interactions. Part of the price that we will pay is that our opinions and feelings will be bruised on a regular basis, but—live with it.

Finally, there is a series of political points. As we saw above, beliefs and thoughts are each individual’s responsibility, just as making a living and putting together a happy life are each individual’s responsibility. The purpose of government is to protect individuals’ rights to pursue these activities. The point for free speech is this: Thoughts and speech do not, no matter how false and offensive they are, violate anyone’s rights. Therefore, there is no basis for government intervention.

There is also a point to be made about democracy, which is a feature of our social system. Democracy means decentralizing decision-making about who is going to wield political power for the next period of time. In order to make that decision, we expect voters to make an informed choice, and the only way that they can make an informed choice is if there is much discussion and much vigorous debate. So, free speech is an essential part of maintaining democracy.

Finally, free speech is a check on the abuses of government power. History teaches us to worry about the abuse of government power, and one indispensable way of checking such abuse is to allow people to criticize the government and to prohibit the government from preventing such criticism.